Description Usage Arguments Details Value Examples
Make an iterator return named values.
1 2 | ## S3 replacement method for class 'iterator'
names(x) <- value
|
x |
an iterator |
value |
a character vector of desired names |
Since this is just a wrapper of iterator, renaming an iterator means additional wrapped function call which adds to overhead thus worse performance.
an iterator
1 2 3 | itr <- iterator_product(1:3, 4:5)
names(itr) <- c("a", "b")
collect(itr, 5)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.